@@ -92,13 +92,18 @@ class Device(object):
         self.conns = kwargs.pop("conns", list(args))
         self._conns_dict = {}
         self.name = kwargs.pop("name", self.__class__.__name__)
-        self.bcc = kwargs.pop("bcc", None)
+        self.bctrl = kwargs.pop("bctrl", None) or kwargs.pop("bcc", None)
         self.prompt = PromptReplacement()
         self._logger = logging.getLogger("{}:{}".format(
             __name__,
             self.name
         ))
 
+    @property
+    def bcc(self):
+        self.log("DEPRECATED: use bctrl instead of bcc")
+        return self.bctrl
+
     def cmd(self, msg, expect=None, timeout=30, login_timeout=None, do_retcode=True):
         """ Send a :term:`shell command` to the :term:`target device`.
 
@@ -166,7 +171,7 @@ class Device(object):
         self.log("close_all()")
         for c in self.conns:
             c.close()
-        self.bcc.close()
+        self.bctrl.close()
 
     def __str__(self):
         return "{}({}):name={}".format(
